@@ -26,6 +26,7 @@ from json import JSONDecodeError
 import hop
 from hop import Stream, list_topics  # noqa: F401
 from hop.auth import Auth
+from hop.models import JSONBlob
 
 import warnings
 
@@ -226,11 +227,15 @@ class client(Stream):
                         metadata=True,
                         batch_size=self.batch_size,
                         batch_timeout=self.batch_timeout):
-                    try:
-                        payload = json.loads(payload)
-                    except (JSONDecodeError, TypeError) as e:
-                        warnings.warn("Payload is not valid json: {}".format(
-                            e))
+                    # Fix in case message is in new format:
+                    if isinstance(payload, JSONBlob):
+                        payload = payload.content
+                    else:
+                        try:
+                            payload = json.loads(payload)
+                        except (JSONDecodeError, TypeError) as e:
+                            warnings.warn("Payload is not valid "
+                                          "json: {}".format(e))
                     if not callback:
                         print("New message from topic {topic}: {msg}"
                               .format(topic=metadata.topic, msg=payload))
